==> klayout-0.9.tar.gz: klayout-0.9/src/SelectCellViewFormImpl.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "SelectCellViewFormImpl.h"
#include "layCellView.h"


// ------------------------------------------------------------

SelectCellViewFormImpl::SelectCellViewFormImpl (QWidget *parent, const char *name, Qt::WFlags fl)
  : QDialog (parent, name, fl), Ui::SelectCellViewForm ()
{
  Ui::SelectCellViewForm::setupUi (this);

  cvs_lb->setSelectionMode (Q3ListBox::Multi);

  // signals and slots connections
  connect( ok_button, SIGNAL( clicked() ), this, SLOT( accept() ) );
  connect( cancel_button, SIGNAL( clicked() ), this, SLOT( reject() ) );
  connect( select_all_pb, SIGNAL( clicked() ), this, SLOT( select_all() ) );
}

void 
SelectCellViewFormImpl::set_title (const std::string &title)
{
  title_lbl->setText (title.c_str ());
}
  
void 
SelectCellViewFormImpl::set_caption (const std::string &caption)
{
  setCaption (caption.c_str ());
}
  
void 
SelectCellViewFormImpl::tell_cellview (const lay::CellView &cv)
{
  cvs_lb->insertItem (cv->filename ().c_str ());
  cvs_lb->setCurrentItem (0);
  cvs_lb->setSelected (0, true);
}

bool 
SelectCellViewFormImpl::all_selected () const
{
  for (int i = 0; i < int (cvs_lb->count ()); ++i) {
    if (! cvs_lb->isSelected (i)) {
      return false;
    }
  }
  return true;
}

std::vector <int> 
SelectCellViewFormImpl::selected_cellviews () const
{
  std::vector <int> res;

  for (int i = 0; i < int (cvs_lb->count ()); ++i) {
    if (cvs_lb->isSelected (i)) {
      res.push_back (i);
    }
  }

  return res;
}

void 
SelectCellViewFormImpl::select_all ()
{
  cvs_lb->selectAll (true);
}

==> klayout-0.10.tar.gz: klayout-0.10/src/SelectCellViewFormImpl.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "SelectCellViewFormImpl.h"
#include "layCellView.h"


// ------------------------------------------------------------

SelectCellViewFormImpl::SelectCellViewFormImpl (QWidget *parent, const char *name, Qt::WFlags fl)
  : QDialog (parent, name, fl), Ui::SelectCellViewForm ()
{
  Ui::SelectCellViewForm::setupUi (this);

  // signals and slots connections
  connect( ok_button, SIGNAL( clicked() ), this, SLOT( accept() ) );
  connect( cancel_button, SIGNAL( clicked() ), this, SLOT( reject() ) );
  connect( select_all_pb, SIGNAL( clicked() ), this, SLOT( select_all() ) );
}

void 
SelectCellViewFormImpl::set_title (const std::string &title)
{
  title_lbl->setText (title.c_str ());
}
  
void 
SelectCellViewFormImpl::set_caption (const std::string &caption)
{
  setCaption (caption.c_str ());
}
  
void 
SelectCellViewFormImpl::tell_cellview (const lay::CellView &cv)
{
  cvs_lb->addItem (cv->filename ().c_str ());
  cvs_lb->setCurrentItem (0);
  cvs_lb->setItemSelected (cvs_lb->item (0), true);
}

bool 
SelectCellViewFormImpl::all_selected () const
{
  for (int i = 0; i < int (cvs_lb->count ()); ++i) {
    if (! cvs_lb->isItemSelected (cvs_lb->item (i))) {
      return false;
    }
  }
  return true;
}

std::vector <int> 
SelectCellViewFormImpl::selected_cellviews () const
{
  std::vector <int> res;

  for (int i = 0; i < int (cvs_lb->count ()); ++i) {
    if (cvs_lb->isItemSelected (cvs_lb->item (i))) {
      res.push_back (i);
    }
  }

  return res;
}

void 
SelectCellViewFormImpl::select_all ()
{
  cvs_lb->clearSelection ();  //  without this, not all items may be selected in "selectAll"
  cvs_lb->selectAll ();
}
